# HG changeset patch
# User Nathan Crapo <nathan@n4nc3o.com>
# Date 1465700287 21600
#      Sat Jun 11 20:58:07 2016 -0600
# Node ID b5f69002cb9f88cd3b1a3b955f071bac11434f0a
# Parent  c26bf979eff5f68e4504d3577e91d205556f4017
Make radio model identification for TH-7800 and TH-9800 more specific so they don't interfere with each other, or completely different radios.  The TH-7800 was ahead of the TH-9800 in the list of Radios to identify against, so Chirp would use it for TH-7800 _and_ TH-9800 radios.  This patch makes both TH-7800 and TH-9800 drivers check their model more carefully so order of Radios Classes doesn't matter.  It's more robust that way.

TH-7800 seems to use "TH9800" for a model string too.  Check for a "TH9800" _or_ "TH7800" string in the th7800.py driver in case TYT doesn't consistently set the model or in case owners change their model name.

Fixes #3737.

diff -r c26bf979eff5 -r b5f69002cb9f chirp/drivers/th7800.py
--- a/chirp/drivers/th7800.py	Fri Jun 10 05:41:35 2016 -0700
+++ b/chirp/drivers/th7800.py	Sat Jun 11 20:58:07 2016 -0600
@@ -696,7 +696,21 @@
 
     @classmethod
     def match_model(cls, filedata, filename):
-        return len(filedata) == cls._memsize
+        if len(filedata) != cls._memsize:
+            return False
+        # TYT used TH9800 as model for TH-7800 _AND_ TH-9800.  Check
+        # for TH7800 in case they fix it or if users update the model
+        # in their own radio.
+        if not (filedata[0xfe18:0xfe1e] == "TH9800" or
+                filedata[0xfe18:0xfe1e] == "TH7800"):
+            return False
+        # TH-7800 bandlimits differ from TH-9800.  First band Invalid
+        # (zero).
+        first_bandlimit = struct.unpack("BBBBBBBBBBBBBBBB",
+                                        filedata[0xfe40:0xfe50])
+        if not all(v == 0 for v in first_bandlimit):
+            return False
+        return True
 
     @classmethod
     def get_prompts(cls):
diff -r c26bf979eff5 -r b5f69002cb9f chirp/drivers/th9800.py
--- a/chirp/drivers/th9800.py	Fri Jun 10 05:41:35 2016 -0700
+++ b/chirp/drivers/th9800.py	Sat Jun 11 20:58:07 2016 -0600
@@ -757,7 +757,18 @@
 
     @classmethod
     def match_model(cls, filedata, filename):
-        return len(filedata) == cls._memsize
+        if len(filedata) != cls._memsize:
+            return False
+        # TYT set this model for TH-7800 _AND_ TH-9800
+        if not filedata[0xfe18:0xfe1e] == "TH9800":
+            return False
+        # TH-9800 bandlimits differ from TH-7800.  First band is used
+        # (non-zero).
+        first_bandlimit = struct.unpack("BBBBBBBBBBBBBBBB",
+                                        filedata[0xfe40:0xfe50])
+        if all(v == 0 for v in first_bandlimit):
+            return False
+        return True
 
     @classmethod
     def get_prompts(cls):
